==> knowledgeroot_0.9.7.3.orig.tar.gz: knowledgeroot-0.9.7.3/move.php <==
<?php
// set version
$version = "0.9.7.3";

// load requiered files
require_once("config/config.inc.php");
require_once("include/init.php");

// init tree
$CLASS['tree'] = new categoryTree();
$CLASS['tree']->start($CLASS,TRUE,"#");

if($CLASS['vars']['knowledgeroot']['charset'] != "") {
	header("Content-Type: text/html; charset=".$CLASS['vars']['knowledgeroot']['charset']."");
	echo '<?xml version="1.0" encoding="'.$CLASS['vars']['knowledgeroot']['charset'].'"?>';
} else {
	echo '<?xml version="1.0" encoding="iso-8859-1"?>';
}
?>
<!DOCTYPE html
     PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<?php
	$CLASS['kr_header']->show_header();
?>
</head>
<body>

<div style="display: none;" id="messagebox">
	<div id="msg" class="loading"><?php echo $CLASS['language']->get['messagebox']['loading']; ?></div>
</div>

<div class="movetitle">
<?php echo $CLASS['language']->get['moveto']; ?>
</div>
<table><tr>
<td id="treecontainer">
 	<!-- <a href="#" onClick="ShowHide('tree');">#</a> -->
	<div id="treeopener" <?php if($CLASS['vars']['menu']['type'] == "static") { echo "style=\"display:none;\""; } else { echo "style=\"display:block;\""; } ?>>
		<div id="treeshow">
			<a href="#" border="0" onclick="ShowTree();" alt="<?php echo $CLASS['language']->get['tree']['showtree']; ?>"><img id="treeshowimg" src="images/right.gif" width="22" title="<?php echo $CLASS['language']->get['tree']['showtree']; ?>" /></a>
		</div>
	</div>

 	<div id="tree" <?php if($CLASS['vars']['menu']['type'] == "static") { echo "style=\"display:block;\""; } else { echo "style=\"display:none; position:absolute;\""; } ?>>
<?php
	// show tree
	$CLASS['tree']->open = $_SESSION['open'];
	$CLASS['tree']->buildTree(0);
?>
	</div>
 </td>
</tr></table>
</body>
</html>
<?php
	$CLASS['db']->close();
?>

==> knowledgeroot_0.9.8.5.orig.tar.gz: knowledgeroot-0.9.8.5/move.php <==
<?php

if(!is_file("config/config.inc.php")) {
	echo "<html><body>No configuration file found! Please make a <a href=\"install.php\">install</a>!</body></html>";
	exit();
}

// load requiered files
require_once("config/config.inc.php");
require_once("include/init.php");

// init tree
$CLASS['tree'] = new categoryTree();
$CLASS['tree']->start($CLASS,'move',"#");

if($CLASS['vars']['knowledgeroot']['charset'] != "") {
	header("Content-Type: text/html; charset=".$CLASS['vars']['knowledgeroot']['charset']."");
	echo '<?xml version="1.0" encoding="'.$CLASS['vars']['knowledgeroot']['charset'].'"?>';
} else {
	echo '<?xml version="1.0" encoding="iso-8859-1"?>';
}
?>
<!DOCTYPE html
     PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<?php
	$CLASS['kr_header']->show_header();
?>
</head>
<body>

<div style="display: none;" id="messagebox">
	<div id="msg" class="loading"><?php echo $CLASS['language']->get['messagebox']['loading']; ?></div>
</div>

<div class="movetitle">
<?php echo $CLASS['language']->get['moveto']; ?>
</div>
<?php
if(isset($_SESSION['admin']) && $_SESSION['admin'] == 1 && isset($_GET['type']) && $_GET['type'] == "page") {
?>
<div id="toroot">
<input class="button" onclick="window.opener.document.forms.move.to.value = '0'; window.opener.document.forms.move.submit(); window.close();" type="button" name="submit" value="<?php echo $CLASS['language']->get['movetoroot']; ?>">
</div>
<?php
}
?>
<table><tr>
<td id="treecontainer">
 	<!-- <a href="#" onClick="ShowHide('tree');">#</a> -->
	<div id="treeopener" <?php if($CLASS['vars']['menu']['type'] == "static") { echo "style=\"display:none;\""; } else { echo "style=\"display:block;\""; } ?>>
		<div id="treeshow">
			<a href="#" border="0" onclick="ShowTree();" alt="<?php echo $CLASS['language']->get['tree']['showtree']; ?>"><img id="treeshowimg" src="images/right.gif" width="22" title="<?php echo $CLASS['language']->get['tree']['showtree']; ?>" /></a>
		</div>
	</div>

 	<div id="tree" <?php if($CLASS['vars']['menu']['type'] == "static") { echo "style=\"display:block;\""; } else { echo "style=\"display:none; position:absolute;\""; } ?>>
<?php
	// show tree
	$CLASS['tree']->open = $_SESSION['open'];
	$CLASS['tree']->buildTree(0);
?>
	</div>
 </td>
</tr></table>
<div id="toroot">
<input class="button" onclick="window.close();" type="button" name="submit" value="<?php echo $CLASS['language']->get['moveclose']; ?>">
</div>
</body>
</html>
<?php
	$CLASS['db']->close();
?>
